@@ -55,7 +55,7 @@
 #' @examples
 #' \dontrun{
 #' ## Example 1: SI Model
-#' param <- param.icm(trans.rate = 0.2, act.rate = 0.25)
+#' param <- param.icm(inf.prob = 0.2, act.rate = 0.25)
 #' init <- init.icm(s.num = 500, i.num = 1)
 #' control <- control.icm(type = "SI", nsteps = 500, nsims = 10)
 #' mod1 <- icm(param, init, control)
@@ -63,7 +63,7 @@
 #' plot(mod1)
 #'
 #' ## Example 2: SIR Model
-#' param <- param.icm(trans.rate = 0.2, act.rate = 0.25, rec.rate = 1/50)
+#' param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
 #' init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
 #' control <- control.icm(type = "SIR", nsteps = 500, nsims = 10)
 #' mod2 <- icm(param, init, control)
@@ -71,7 +71,7 @@
 #' plot(mod2)
 #'
 #' ## Example 3: SIS Model
-#' param <- param.icm(trans.rate = 0.2, act.rate = 0.25, rec.rate = 1/50)
+#' param <- param.icm(inf.prob = 0.2, act.rate = 0.25, rec.rate = 1/50)
 #' init <- init.icm(s.num = 500, i.num = 1)
 #' control <- control.icm(type = "SIS", nsteps = 500, nsims = 10)
 #' mod3 <- icm(param, init, control)
@@ -79,7 +79,7 @@
 #' plot(mod3)
 #'
 #' ## Example 4: SI Model with Vital Dynamics (Two-Group)
-#' param <- param.icm(trans.rate = 0.4,  trans.rate.g2 = 0.1,
+#' param <- param.icm(inf.prob = 0.4,  inf.prob.g2 = 0.1,
 #'                    act.rate = 0.25, balance = "g1",
 #'                    b.rate = 1/100, b.rate.g2 = NA,
 #'                    ds.rate = 1/100, ds.rate.g2 = 1/100,
@@ -109,8 +109,7 @@ icm <- function(param, init, control) {
 
       ## User Modules
       bim <- grep(".FUN", names(formals(control.icm)), value = TRUE)
-      um <- which(grepl(".FUN", names(control)) &
-                    !(names(control) %in% bim))
+      um <- which(grepl(".FUN", names(control)) & !(names(control) %in% bim))
       if (length(um) > 0) {
         for (i in 1:length(um)) {
           umn <- names(control)[um[i]]
