@@ -23,11 +23,7 @@
 #'        full legend, and "lim" for limited legend (see details).
 #' @param leg.name character string to use for legend, with the default
 #'        determined automatically based on the \code{y} input.
-#' @param leg.cex legend scale size (default of 0.8).
-#' @param xlim x-axis scale limits for plot, with default based on model time
-#'        steps.
-#' @param ylim y-axis scale limits for plot, with default based on range of data.
-#' @param main character string for main plot title.
+#' @param leg.cex legend scale size.
 #' @param axs plot axis type (see \code{\link{par}} for details), with default
 #'        of "r".
 #' @param add if \code{TRUE}, new plot window is not called and lines are added to
@@ -79,7 +75,7 @@
 #'
 #' @examples
 #' # Deterministic SIR model with varying act rate
-#' param <- param.dcm(trans.rate = 0.2, act.rate = 1:10,
+#' param <- param.dcm(inf.prob = 0.2, act.rate = 1:10,
 #'                    rec.rate = 1/3, b.rate = 0.011, ds.rate = 0.01,
 #'                    di.rate = 0.03, dr.rate = 0.01)
 #' init <- init.dcm(s.num = 1000, i.num = 1, r.num = 0)
@@ -108,14 +104,11 @@ plot.dcm <- function(x,
                      col,
                      lwd,
                      lty,
-                     alpha,
+                     alpha = 0.9,
                      leg,
                      leg.name,
-                     leg.cex,
-                     xlim,
-                     ylim,
-                     main,
-                     axs,
+                     leg.cex = 0.8,
+                     axs = "r",
                      add = FALSE,
                      ...) {
 
@@ -129,6 +122,10 @@ plot.dcm <- function(x,
   noleg <- ifelse(missing(leg), TRUE, FALSE)
 
 
+  ## Dot args
+  da <- list(...)
+
+
   ## Model dimensions
   nsteps <- max(x$control$dt)
   nruns <- x$control$nruns
@@ -145,18 +142,11 @@ plot.dcm <- function(x,
   groups <- x$param$groups
   type <- x$control$type
 
-  ## Universal defaults
-  if (noleg == TRUE) {
-    leg <- "n"
-  }
-  if (missing(alpha)) {
-    alpha <- 0.9
-  }
-  if (missing(leg.cex)) {
-    leg.cex <- 0.8
-  }
-  if (missing(main)) {
+  ## Main title default
+  if (is.null(da$main)) {
     main <- paste("DCM", x$control$type, "Model")
+  } else {
+    main <- da$main
   }
 
 
@@ -192,15 +182,16 @@ plot.dcm <- function(x,
   }
 
 
-  ## Defaults for ylim, xlim, axs
-  if (missing(ylim)) {
+  ## Defaults for ylim, xlim
+  if (is.null(da$ylim)) {
     ylim <- c(0, ymax)
+  } else {
+    ylim <- da$ylim
   }
-  if (missing(xlim)) {
+  if (is.null(da$xlim)) {
     xlim <- c(0, nsteps)
-  }
-  if (missing(axs)) {
-    axs <- "r"
+  } else {
+    xlim <- da$xlim
   }
 
 
@@ -237,12 +228,12 @@ plot.dcm <- function(x,
       Time <- Number <- 1
       plot(Time, Number, type = "n", bty = "n",
            xaxs = axs, yaxs = axs, xlim = xlim, ylim = ylim,
-           main = main, ...)
+           main = main)
     } else {
       Time <- Prevalence <- 1
       plot(Time, Prevalence, type = "n", bty = "n",
            xaxs = axs, yaxs = axs, xlim = xlim, ylim = ylim,
-           main = main, ...)
+           main = main)
     }
   }
 
@@ -464,14 +455,6 @@ plot.dcm <- function(x,
     }
   }
 
-  ## Mtext
-  if (add == FALSE) {
-    if (nruns > 1 & lcomp > 1) {
-      mt <- paste("Run =", run)
-      mtext(mt, 3, line = 0, cex = 0.75)
-    }
-  }
-
 }
 
 
@@ -505,10 +488,7 @@ plot.dcm <- function(x,
 #' @param qnts.alpha transparency level for quantile polygons, where 0 =
 #'        transparent and 1 = opaque (see \code{\link{transco}}).
 #' @param leg if \code{TRUE}, plot default legend.
-#' @param leg.cex legend scale size, with default of 0.8.
-#' @param xlim x-axis scale limits for plot, with default based on model time steps.
-#' @param ylim y-axis scale limits for plot, with default based on range of data.
-#' @param main character string for main plot title.
+#' @param leg.cex legend scale size.
 #' @param axs plot axis type (see \code{\link{par}} for details), with default
 #'        to \code{"r"}.
 #' @param add if \code{TRUE}, new plot window is not called and lines are added to
@@ -550,7 +530,7 @@ plot.dcm <- function(x,
 #' @examples
 #' \dontrun{
 #' ## Example 1: Plotting multiple compartment values from SIR model
-#' param <- param.icm(trans.rate = 0.5, act.rate = 0.5, rec.rate = 0.02)
+#' param <- param.icm(inf.prob = 0.5, act.rate = 0.5, rec.rate = 0.02)
 #' init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
 #' control <- control.icm(type = "SIR", nsteps = 100,
 #'                        nsims = 3, verbose = FALSE)
@@ -558,7 +538,7 @@ plot.dcm <- function(x,
 #' plot(mod)
 #'
 #' ## Example 2: Plot only infected with specific output from SI model
-#' param <- param.icm(trans.rate = 0.25, act.rate = 0.25)
+#' param <- param.icm(inf.prob = 0.25, act.rate = 0.25)
 #' init <- init.icm(s.num = 500, i.num = 10)
 #' control <- control.icm(type = "SI", nsteps = 100,
 #'                        nsims = 3, verbose = FALSE)
@@ -584,11 +564,8 @@ plot.icm <- function(x,
                      qnts.col,
                      qnts.alpha,
                      leg,
-                     leg.cex,
-                     xlim,
-                     ylim,
-                     main,
-                     axs,
+                     leg.cex = 0.8,
+                     axs = "r",
                      add = FALSE,
                      ...) {
 
@@ -611,6 +588,9 @@ plot.icm <- function(x,
     modes <- x$param$modes
   }
 
+  # dotargs
+  da <- list(...)
+
 
   # Compartments ------------------------------------------------------------
   nocomp <- ifelse(missing(y), TRUE, FALSE)
@@ -729,13 +709,17 @@ plot.icm <- function(x,
 
 
   # Missing args ------------------------------------------------------------
-  if (missing(xlim)) {
+  if (is.null(da$xlim)) {
     xlim <- c(0, nsteps)
+  } else {
+    xlim <- da$xlim
   }
-  if (missing(ylim)) {
+  if (is.null(da$ylim)) {
     ylim <- c(0, max.prev)
+  } else {
+    ylim <- da$ylim
   }
-  if (missing(main)) {
+  if (is.null(da$main)) {
     if (class(x) == "icm") {
       modclass <- "ICM"
     }
@@ -743,9 +727,8 @@ plot.icm <- function(x,
       modclass <- "Network"
     }
     main <- paste(modclass, type, "Model")
-  }
-  if (missing(axs)) {
-    axs <- "r"
+  } else {
+    main <- da$main
   }
 
 
@@ -755,12 +738,12 @@ plot.icm <- function(x,
       Time <- Number <- 1
       plot(Time, Number, type = "n", bty = "n",
            xaxs = axs, yaxs = axs, xlim = xlim, ylim = ylim,
-           main = main, ...)
+           main = main)
     } else {
       Time <- Prevalence <- 1
       plot(Time, Prevalence, type = "n", bty = "n",
            xaxs = axs, yaxs = axs, xlim = xlim, ylim = ylim,
-           main = main, ...)
+           main = main)
     }
   }
 
@@ -874,9 +857,6 @@ plot.icm <- function(x,
   if (missing(leg)) {
     leg <- FALSE
   }
-  if (missing(leg.cex)) {
-    leg.cex <- 0.8
-  }
   if (leg == TRUE) {
     if (modes == 2 & nocomp) {
       legend("topright", legend = y, lty = mean.lty, lwd = 3,
@@ -1358,7 +1338,7 @@ plot.netdx <- function(x,
 #'               verbose = FALSE)
 #'
 #' # Simulate the epidemic model
-#' param <- param.net(trans.rate = 0.3, trans.rate.m2 = 0.15)
+#' param <- param.net(inf.prob = 0.3, inf.prob.m2 = 0.15)
 #' init <- init.net(i.num = 10, i.num.m2 = 10)
 #' control <- control.net(type = "SI", nsteps = 100, nsims = 5,
 #'                        verbose = FALSE, save.nwstats = TRUE,
@@ -1764,7 +1744,7 @@ plot.netsim <- function(x,
 #' @examples
 #' \dontrun{
 #' ## Example 1: DCM SIR model with varying act.rate
-#' param <- param.dcm(trans.rate = 0.2, act.rate = 5:7,
+#' param <- param.dcm(inf.prob = 0.2, act.rate = 5:7,
 #'                    rec.rate = 1/3, b.rate = 1/90, ds.rate = 1/100,
 #'                    di.rate = 1/35, dr.rate = 1/100)
 #' init <- init.dcm(s.num = 1000, i.num = 1, r.num = 0)
@@ -1773,7 +1753,7 @@ plot.netsim <- function(x,
 #' comp_plot(mod1, at = 25, run = 3)
 #'
 #' ## Example 2: ICM SIR model with 3 simulations
-#' param <- param.icm(trans.rate = 0.2, act.rate = 3, rec.rate = 1/50,
+#' param <- param.icm(inf.prob = 0.2, act.rate = 3, rec.rate = 1/50,
 #'                    b.rate = 1/100, ds.rate = 1/100,
 #'                    di.rate = 1/90, dr.rate = 1/100)
 #' init <- init.icm(s.num = 500, i.num = 1, r.num = 0)
