@@ -1,4 +1,4 @@
-context("netattr")
+context("Network attributes with births")
 
 test_that("Updating attributes in open populations", {
   nw <- network.initialize(n = 50, bipartite = 25, directed = FALSE)
@@ -19,10 +19,10 @@ test_that("Updating attributes in open populations", {
 
   probs <- c(0.2055, 0.0088, 0.0614, 0)
   durs <- c(3, 100, 9, 10)
-  trans.rates <- rep(probs, durs)
-  trans.ratesf <- trans.rates*2
-  param <- param.net(trans.rate = trans.ratesf, act.rate = 1,
-                     trans.rate.m2 = trans.rates,
+  inf.probs <- rep(probs, durs)
+  inf.probsf <- inf.probs*2
+  param <- param.net(inf.prob = inf.probsf, act.rate = 1,
+                     inf.prob.m2 = inf.probs,
                      b.rate = 0.05, b.rate.m2 = NA,
                      ds.rate = 0.002, ds.rate.m2 = 0.002,
                      di.rate = 0.008, di.rate.m2 = 0.008)
@@ -44,12 +44,14 @@ test_that("Serosorting model in open population", {
   infIds <- sample(1:n, n*prev)
   nw <- set.vertex.attribute(nw, "status", 0)
   nw <- set.vertex.attribute(nw, "status", 1, infIds)
+  nw <- set.vertex.attribute(nw, "race", rbinom(n, 1, 0.5))
 
-  formation <- ~ edges + nodefactor("status") + nodematch("status")
-  target.stats <- c(18, 3, 15)
+  formation <- ~ edges + nodefactor("status") +
+                 nodematch("status") + nodematch("race")
+  target.stats <- c(18, 3, 15, 10)
 
   dissolution <- ~offset(edges)
-  coef.diss <- dissolution_coefs(dissolution, 50, d.rate = 0.005)
+  coef.diss <- dissolution_coefs(dissolution, 50, d.rate = 0.01)
 
   est <- netest(nw,
                 formation,
@@ -58,8 +60,8 @@ test_that("Serosorting model in open population", {
                 coef.diss,
                 verbose = FALSE)
 
-  param <- param.net(trans.rate = 0.03, b.rate = 0.005,
-                     ds.rate = 0.005, di.rate = 0.005)
+  param <- param.net(inf.prob = 0.03, b.rate = 0.01,
+                     ds.rate = 0.01, di.rate = 0.01)
   init <- init.net()
   control <- control.net(type = "SI", nsteps = 10, nsims = 1,
                          nwstats.formula = ~ edges +
