@@ -1,4 +1,4 @@
-context("netsim")
+context("Standard network models")
 
 nw <- network.initialize(n = 50, directed = FALSE)
 nw <- set.vertex.attribute(nw, "race", rbinom(50, 1, 0.5))
@@ -13,43 +13,49 @@ est <- netest(
 # Edges + nodematch, one-mode, closed
 
 test_that("netsim for edges only, SI, one-mode, closed, 1 sim", {
-  param <- param.net(trans.rate = 0.3, act.rate = 0.5)
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsims = 1, nsteps = 5, verbose = FALSE)
   mod <- netsim(est, param, init, control)
+  expect_is(mod, "netsim")
 })
 
 test_that("netsim for edges only, SI, one-mode, closed, 2 sim", {
-  param <- param.net(trans.rate = 0.3, act.rate = 0.5)
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsims = 2, nsteps = 5, verbose = FALSE)
   mod <- netsim(est, param, init, control)
+  expect_is(mod, "netsim")
 })
 
 test_that("netsim for edges only, SIS, one-mode, closed, 1 sim", {
-  param <- param.net(trans.rate = 0.3, act.rate = 0.5, rec.rate = 0.05)
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5, rec.rate = 0.05)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SIS", nsims = 1, nsteps = 5, verbose = FALSE)
   mod <- netsim(est, param, init, control)
+  expect_is(mod, "netsim")
 })
 
 test_that("netsim for edges only, SIS, one-mode, closed, 2 sim", {
-  param <- param.net(trans.rate = 0.3, act.rate = 0.5, rec.rate = 0.05)
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5, rec.rate = 0.05)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SIS", nsims = 2, nsteps = 5, verbose = FALSE)
   mod <- netsim(est, param, init, control)
+  expect_is(mod, "netsim")
 })
 
 test_that("netsim for edges only, SIR, one-mode, closed, 1 sim", {
-  param <- param.net(trans.rate = 0.3, act.rate = 0.5, rec.rate = 0.05)
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5, rec.rate = 0.05)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsims = 1, nsteps = 5, verbose = FALSE)
   mod <- netsim(est, param, init, control)
+  expect_is(mod, "netsim")
 })
 
 test_that("netsim for edges only, SIR, one-mode, closed, 2 sim", {
-  param <- param.net(trans.rate = 0.3, act.rate = 0.5, rec.rate = 0.05)
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5, rec.rate = 0.05)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsims = 2, nsteps = 5, verbose = FALSE)
   mod <- netsim(est, param, init, control)
+  expect_is(mod, "netsim")
 })
